###################################################################################################################################################
# Copyright 2015 Orchid Systems 
# -----------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an "as is" basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
# -------------------
# Updated: 2018/08/23 - includes system access to check to prevent script from running during D.I.C, Import, Export, etc.
###################################################################################################################################################

from accpac import *
# This sample script sends an email when an OE Order is created or updated.

# onOpen is called when the view is opened.
# Return Continue to enable the macro.
# Return 0 to disable the macro.
# If you return anything else then the view will not load.
def onOpen():
	if rotoID != "OE0520":
		showError("This script is intended for OE0520 (OEORDH) only, not " + rotoID)
		return 0 # don't do anything since the view is not OEORDH
		
	# Check system access to prevent running the script during Data Integrity Check, Import, Export, etc:
	if int(me.getAccess()) != 0:
		return 0.# do not run the script. System Access is not Normal.

	return Continue

def onAfterInsert(result):
	if result != 0:
		return
	SendMail()

def onAfterUpdate(result):
	if result != 0:
		return
	SendMail()

def SendMail():

	if me.get("SHPEMAIL") == "":
		return

	# vARCUST = viewOpen("AR0024", 1)
	# viewPut(vARCUST, "IDCUST", viewGet("CUSTOMER"))
	# viewRead(vARCUST)

	m = emailStart()
	emailTo(m, "{SHPEMAIL}")
	# emailCC(m, "someone@company.com")
	emailSubject(m, "Order " + me.get("ORDNUMBER") + " created")

	# You can set a text email body with emailBody, or a HTML body with emailHtml
	# emailBody(m, "An order was created.")

	lineTemplate = "<tr><td>{ITEM}</td><td align=right>{QTYORDERED:D0}</td><td align=right>${EXTINVMISC:D2}</td></tr>"
	html = """<html><body>Dear {SHPNAME},<br>Thank you for your order.<br><br>
<table border="0" cellspacing="0" cellpadding="4">
<tr style="font-weight: bold;"><td>Item</td><td align=right>Quantity</td><td align=right>Cost</td></tr>
{DETAILS}
</table>
</body></html>"""

	# Add the details
	d = View("OE0500", 1)
	d.recordClear()
	d.browse("ORDUNIQ=" + str(me.get("ORDUNIQ")), 1)
	lines = ""
	while d.fetch() == 0:
		lines = lines + d.replaceFields(lineTemplate)
	html = html.replace("{DETAILS}", lines)
	emailHtml(m, html)
	# emailAttach(m, fileName, mimeType)
	# emailAttach(m, "C:\\files\\somepdf.pdf", "application/pdf")
	emailSend(m)
